pub struct BaseArray<'a> {
data: FontData<'a>,
mark_class_count: u16,
}Expand description
Part of MarkBasePosFormat1
Fields
data: FontData<'a>mark_class_count: u16Implementations
Sourceimpl<'a> BaseArray<'a>
impl<'a> BaseArray<'a>
pub const MIN_SIZE: usize = u16::RAW_BYTE_LEN
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn base_count(&self) -> u16
pub fn base_count(&self) -> u16
Number of BaseRecords
Sourcepub fn base_records(&self) -> ComputedArray<'a, BaseRecord<'a>>
pub fn base_records(&self) -> ComputedArray<'a, BaseRecord<'a>>
Array of BaseRecords, in order of baseCoverage Index.
pub(crate) fn mark_class_count(&self) -> u16
pub fn base_count_byte_range(&self) -> Range<usize> ⓘ
pub fn base_records_byte_range(&self) -> Range<usize> ⓘ