Gpos

Struct Gpos 

pub struct Gpos<'a> {
    data: FontData<'a>,
}
Fields

data: FontData<'a>

Implementations

Source

impl Gpos<'_>

pub fn collect_features( &self, scripts: &IntSet<Tag>, languages: &IntSet<Tag>, features: &IntSet<Tag>, ) -> Result<IntSet<u16>, ReadError>

Return a set of all feature indices underneath the specified scripts, languages and features

pub fn collect_lookups( &self, feature_indices: &IntSet<u16>, ) -> Result<IntSet<u16>, ReadError>

Return a set of lookups referenced by the specified features

pub fn closure_lookups( &self, glyphs: &IntSet<GlyphId>, lookup_indices: &mut IntSet<u16>, ) -> Result<(), ReadError>

Update the set of lookup indices with all lookups reachable from specified glyph set and lookup_indices.

Source

impl<'a> Gpos<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn version(&self) -> MajorMinor

The major and minor version of the GPOS table, as a tuple (u16, u16)

pub fn script_list_offset(&self) -> Offset16

Offset to ScriptList table, from beginning of GPOS table

pub fn script_list(&self) -> Result<ScriptList<'a>, ReadError>

Attempt to resolve script_list_offset.

pub fn feature_list_offset(&self) -> Offset16

Offset to FeatureList table, from beginning of GPOS table

pub fn feature_list(&self) -> Result<FeatureList<'a>, ReadError>

Attempt to resolve feature_list_offset.

pub fn lookup_list_offset(&self) -> Offset16

Offset to LookupList table, from beginning of GPOS table

pub fn lookup_list(&self) -> Result<PositionLookupList<'a>, ReadError>

Attempt to resolve lookup_list_offset.

pub fn feature_variations_offset(&self) -> Option<Nullable<Offset32>>

pub fn feature_variations( &self, ) -> Option<Result<FeatureVariations<'a>, ReadError>>

Attempt to resolve feature_variations_offset.

pub fn version_byte_range(&self) -> Range<usize>

pub fn script_list_offset_byte_range(&self) -> Range<usize>

pub fn feature_list_offset_byte_range(&self) -> Range<usize>

pub fn lookup_list_offset_byte_range(&self) -> Range<usize>

pub fn feature_variations_offset_byte_range(&self) -> Range<usize>