pub struct LigatureArray<'a> {
data: FontData<'a>,
mark_class_count: u16,
}Expand description
Part of MarkLigPosFormat1
Fields
data: FontData<'a>mark_class_count: u16Implementations
Sourceimpl<'a> LigatureArray<'a>
impl<'a> LigatureArray<'a>
Sourceimpl<'a> LigatureArray<'a>
impl<'a> LigatureArray<'a>
pub const MIN_SIZE: usize = u16::RAW_BYTE_LEN
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn ligature_count(&self) -> u16
pub fn ligature_count(&self) -> u16
Number of LigatureAttach table offsets
Sourcepub fn ligature_attach_offsets(&self) -> &'a [BigEndian<Offset16>]
pub fn ligature_attach_offsets(&self) -> &'a [BigEndian<Offset16>]
Array of offsets to LigatureAttach tables. Offsets are from beginning of LigatureArray table, ordered by ligatureCoverage index.
Sourcepub fn ligature_attaches(
&self,
) -> ArrayOfOffsets<'a, LigatureAttach<'a>, Offset16>
pub fn ligature_attaches( &self, ) -> ArrayOfOffsets<'a, LigatureAttach<'a>, Offset16>
A dynamically resolving wrapper for ligature_attach_offsets.
pub(crate) fn mark_class_count(&self) -> u16
pub fn ligature_count_byte_range(&self) -> Range<usize> ⓘ
pub fn ligature_attach_offsets_byte_range(&self) -> Range<usize> ⓘ