pub struct MarkBasePosFormat1<'a> {
data: FontData<'a>,
}Expand description
Mark-to-Base Attachment Positioning Format 1: Mark-to-base Attachment Point
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> MarkBasePosFormat1<'a>
impl<'a> MarkBasePosFormat1<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn pos_format(&self) -> u16
pub fn pos_format(&self) -> u16
Format identifier: format = 1
Sourcepub fn mark_coverage_offset(&self) -> Offset16
pub fn mark_coverage_offset(&self) -> Offset16
Offset to markCoverage table, from beginning of MarkBasePos subtable.
Sourcepub fn mark_coverage(&self) -> Result<CoverageTable<'a>, ReadError>
pub fn mark_coverage(&self) -> Result<CoverageTable<'a>, ReadError>
Attempt to resolve mark_coverage_offset.
Sourcepub fn base_coverage_offset(&self) -> Offset16
pub fn base_coverage_offset(&self) -> Offset16
Offset to baseCoverage table, from beginning of MarkBasePos subtable.
Sourcepub fn base_coverage(&self) -> Result<CoverageTable<'a>, ReadError>
pub fn base_coverage(&self) -> Result<CoverageTable<'a>, ReadError>
Attempt to resolve base_coverage_offset.
Sourcepub fn mark_class_count(&self) -> u16
pub fn mark_class_count(&self) -> u16
Number of classes defined for marks
Sourcepub fn mark_array_offset(&self) -> Offset16
pub fn mark_array_offset(&self) -> Offset16
Offset to MarkArray table, from beginning of MarkBasePos subtable.
Sourcepub fn mark_array(&self) -> Result<MarkArray<'a>, ReadError>
pub fn mark_array(&self) -> Result<MarkArray<'a>, ReadError>
Attempt to resolve mark_array_offset.
Sourcepub fn base_array_offset(&self) -> Offset16
pub fn base_array_offset(&self) -> Offset16
Offset to BaseArray table, from beginning of MarkBasePos subtable.
Sourcepub fn base_array(&self) -> Result<BaseArray<'a>, ReadError>
pub fn base_array(&self) -> Result<BaseArray<'a>, ReadError>
Attempt to resolve base_array_offset.
pub fn pos_format_byte_range(&self) -> Range<usize> ⓘ
pub fn mark_coverage_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn base_coverage_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn mark_class_count_byte_range(&self) -> Range<usize> ⓘ
pub fn mark_array_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn base_array_offset_byte_range(&self) -> Range<usize> ⓘ