MarkLigPosFormat1

Struct MarkLigPosFormat1 

pub struct MarkLigPosFormat1<'a> {
    data: FontData<'a>,
}
Mark-to-Ligature Positioning Format 1: Mark-to-Ligature Attachment

Fields

data: FontData<'a>

Implementations

Source

impl<'a> MarkLigPosFormat1<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn pos_format(&self) -> u16

Format identifier: format = 1

pub fn mark_coverage_offset(&self) -> Offset16

Offset to markCoverage table, from beginning of MarkLigPos subtable.

pub fn mark_coverage(&self) -> Result<CoverageTable<'a>, ReadError>

Attempt to resolve mark_coverage_offset.

pub fn ligature_coverage_offset(&self) -> Offset16

Offset to ligatureCoverage table, from beginning of MarkLigPos subtable.

pub fn ligature_coverage(&self) -> Result<CoverageTable<'a>, ReadError>

Attempt to resolve ligature_coverage_offset.

pub fn mark_class_count(&self) -> u16

Number of defined mark classes

pub fn mark_array_offset(&self) -> Offset16

Offset to MarkArray table, from beginning of MarkLigPos subtable.

pub fn mark_array(&self) -> Result<MarkArray<'a>, ReadError>

Attempt to resolve mark_array_offset.

pub fn ligature_array_offset(&self) -> Offset16

Offset to LigatureArray table, from beginning of MarkLigPos subtable.

pub fn ligature_array(&self) -> Result<LigatureArray<'a>, ReadError>

Attempt to resolve ligature_array_offset.

pub fn pos_format_byte_range(&self) -> Range<usize>

pub fn mark_coverage_offset_byte_range(&self) -> Range<usize>

pub fn ligature_coverage_offset_byte_range(&self) -> Range<usize>

pub fn mark_class_count_byte_range(&self) -> Range<usize>

pub fn mark_array_offset_byte_range(&self) -> Range<usize>

pub fn ligature_array_offset_byte_range(&self) -> Range<usize>