pub struct PairPosFormat1<'a> {
data: FontData<'a>,
}Expand description
Pair Adjustment Positioning Format 1: Adjustments for Glyph Pairs
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> PairPosFormat1<'a>
impl<'a> PairPosFormat1<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn pos_format(&self) -> u16
pub fn pos_format(&self) -> u16
Format identifier: format = 1
Sourcepub fn coverage_offset(&self) -> Offset16
pub fn coverage_offset(&self) -> Offset16
Offset to Coverage table, from beginning of PairPos subtable.
Sourcepub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>
pub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>
Attempt to resolve coverage_offset.
Sourcepub fn value_format1(&self) -> ValueFormat
pub fn value_format1(&self) -> ValueFormat
Defines the types of data in valueRecord1 — for the first glyph in the pair (may be zero).
Sourcepub fn value_format2(&self) -> ValueFormat
pub fn value_format2(&self) -> ValueFormat
Defines the types of data in valueRecord2 — for the second glyph in the pair (may be zero).
Sourcepub fn pair_set_count(&self) -> u16
pub fn pair_set_count(&self) -> u16
Number of PairSet tables
Sourcepub fn pair_set_offsets(&self) -> &'a [BigEndian<Offset16>]
pub fn pair_set_offsets(&self) -> &'a [BigEndian<Offset16>]
Array of offsets to PairSet tables. Offsets are from beginning of PairPos subtable, ordered by Coverage Index.
Sourcepub fn pair_sets(&self) -> ArrayOfOffsets<'a, PairSet<'a>, Offset16>
pub fn pair_sets(&self) -> ArrayOfOffsets<'a, PairSet<'a>, Offset16>
A dynamically resolving wrapper for pair_set_offsets.
pub fn pos_format_byte_range(&self) -> Range<usize> ⓘ
pub fn coverage_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn value_format1_byte_range(&self) -> Range<usize> ⓘ
pub fn value_format2_byte_range(&self) -> Range<usize> ⓘ
pub fn pair_set_count_byte_range(&self) -> Range<usize> ⓘ
pub fn pair_set_offsets_byte_range(&self) -> Range<usize> ⓘ