PairPosFormat2

Struct PairPosFormat2 

pub struct PairPosFormat2<'a> {
    data: FontData<'a>,
}
Pair Adjustment Positioning Format 2: Class Pair Adjustment

Fields

data: FontData<'a>

Implementations

Source

impl<'a> PairPosFormat2<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn pos_format(&self) -> u16

Format identifier: format = 2

pub fn coverage_offset(&self) -> Offset16

Offset to Coverage table, from beginning of PairPos subtable.

pub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>

Attempt to resolve coverage_offset.

pub fn value_format1(&self) -> ValueFormat

ValueRecord definition — for the first glyph of the pair (may be zero).

pub fn value_format2(&self) -> ValueFormat

ValueRecord definition — for the second glyph of the pair (may be zero).

pub fn class_def1_offset(&self) -> Offset16

Offset to ClassDef table, from beginning of PairPos subtable — for the first glyph of the pair.

pub fn class_def1(&self) -> Result<ClassDef<'a>, ReadError>

Attempt to resolve class_def1_offset.

pub fn class_def2_offset(&self) -> Offset16

Offset to ClassDef table, from beginning of PairPos subtable — for the second glyph of the pair.

pub fn class_def2(&self) -> Result<ClassDef<'a>, ReadError>

Attempt to resolve class_def2_offset.

pub fn class1_count(&self) -> u16

Number of classes in classDef1 table — includes Class 0.

pub fn class2_count(&self) -> u16

Number of classes in classDef2 table — includes Class 0.

pub fn class1_records(&self) -> ComputedArray<'a, Class1Record<'a>>

Array of Class1 records, ordered by classes in classDef1.

pub fn pos_format_byte_range(&self) -> Range<usize>

pub fn coverage_offset_byte_range(&self) -> Range<usize>

pub fn value_format1_byte_range(&self) -> Range<usize>

pub fn value_format2_byte_range(&self) -> Range<usize>

pub fn class_def1_offset_byte_range(&self) -> Range<usize>

pub fn class_def2_offset_byte_range(&self) -> Range<usize>

pub fn class1_count_byte_range(&self) -> Range<usize>

pub fn class2_count_byte_range(&self) -> Range<usize>

pub fn class1_records_byte_range(&self) -> Range<usize>

Source

impl PairPosFormat2<'_>

pub fn values( &self, class1: u16, class2: u16, context: &ValueContext<'_>, ) -> Result<[Value; 2], ReadError>

Returns the pair of values for the given classes, optionally accounting for variations.

The class1 and class2 parameters can be computed by passing the first and second glyphs of the pair to the ClassDefs returned by Self::class_def1 and Self::class_def2 respectively.