pub struct PairSet<'a> {
data: FontData<'a>,
value_format1: ValueFormat,
value_format2: ValueFormat,
}Expand description
Part of PairPosFormat1
Fields
data: FontData<'a>value_format1: ValueFormatvalue_format2: ValueFormatImplementations
Sourceimpl<'a> PairSet<'a>
impl<'a> PairSet<'a>
Sourcepub fn read(
data: FontData<'a>,
value_format1: ValueFormat,
value_format2: ValueFormat,
) -> Result<Self, ReadError>
pub fn read( data: FontData<'a>, value_format1: ValueFormat, value_format2: ValueFormat, ) -> Result<Self, ReadError>
A constructor that requires additional arguments.
This type requires some external state in order to be parsed.
Sourceimpl<'a> PairSet<'a>
impl<'a> PairSet<'a>
pub const MIN_SIZE: usize = u16::RAW_BYTE_LEN
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn pair_value_count(&self) -> u16
pub fn pair_value_count(&self) -> u16
Number of PairValueRecords
Sourcepub fn pair_value_records(&self) -> ComputedArray<'a, PairValueRecord>
pub fn pair_value_records(&self) -> ComputedArray<'a, PairValueRecord>
Array of PairValueRecords, ordered by glyph ID of the second glyph.
pub(crate) fn value_format1(&self) -> ValueFormat
pub(crate) fn value_format2(&self) -> ValueFormat
pub fn pair_value_count_byte_range(&self) -> Range<usize> ⓘ
pub fn pair_value_records_byte_range(&self) -> Range<usize> ⓘ