pub struct SinglePosFormat2<'a> {
data: FontData<'a>,
}Expand description
Single Adjustment Positioning Format 2: Array of Positioning Values
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> SinglePosFormat2<'a>
impl<'a> SinglePosFormat2<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn pos_format(&self) -> u16
pub fn pos_format(&self) -> u16
Format identifier: format = 2
Sourcepub fn coverage_offset(&self) -> Offset16
pub fn coverage_offset(&self) -> Offset16
Offset to Coverage table, from beginning of SinglePos subtable.
Sourcepub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>
pub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>
Attempt to resolve coverage_offset.
Sourcepub fn value_format(&self) -> ValueFormat
pub fn value_format(&self) -> ValueFormat
Defines the types of data in the ValueRecords.
Sourcepub fn value_count(&self) -> u16
pub fn value_count(&self) -> u16
Number of ValueRecords — must equal glyphCount in the Coverage table.
Sourcepub fn value_records(&self) -> ComputedArray<'a, ValueRecord>
pub fn value_records(&self) -> ComputedArray<'a, ValueRecord>
Array of ValueRecords — positioning values applied to glyphs.
pub fn pos_format_byte_range(&self) -> Range<usize> ⓘ
pub fn coverage_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn value_format_byte_range(&self) -> Range<usize> ⓘ
pub fn value_count_byte_range(&self) -> Range<usize> ⓘ
pub fn value_records_byte_range(&self) -> Range<usize> ⓘ